@@ -4,16 +4,14 @@ Main interface for dlm service.
 Usage::
 
     ```python
-    import boto3
+    from boto3.session import Session
     from mypy_boto3_dlm import (
         Client,
         DLMClient,
     )
 
-    session = boto3.Session()
-
-    client: DLMClient = boto3.client("dlm")
-    session_client: DLMClient = session.client("dlm")
+    session = Session()
+    client: DLMClient = session.client("dlm")
     ```
 """
 from .client import DLMClient
