@@ -1,7 +1,7 @@
 """
 Type annotations for dlm service type definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dlm/type_defs.html)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dlm/type_defs/)
 
 Usage::
 
@@ -13,7 +13,9 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import Any, Dict, List, Mapping, Sequence
+from typing import Dict, List, Mapping, Sequence
+
+from typing_extensions import NotRequired
 
 from .literals import (
     GettablePolicyStateValuesType,
@@ -385,7 +387,7 @@ ResponseMetadataTypeDef = TypedDict(
         "RequestId": str,
         "HostId": str,
         "HTTPStatusCode": int,
-        "HTTPHeaders": Dict[str, Any],
+        "HTTPHeaders": Dict[str, str],
         "RetryAttempts": int,
     },
 )
